#include "Image.h"


imageClass::imageClass()
{
	for(int frame = 0; frame < FRAMES; frame++)
	{
		for(int sector = 0; sector < 3; sector++)
		{
			imageData[frame][sector] = 0x0;
		}
		imageData[frame][3] = 0x0;
	}
	currentPattern = 1;
	duration = 5000000;
	spiral();
}

void imageClass::setImageByte(uint8_t data, uint8_t imageFrame, uint8_t sector)
{
	imageData[imageFrame][sector] = data;

}

uint8_t imageClass::getPixels(uint8_t imageFrame, uint8_t sector)
{
	if(sector < 3)
	{
		return imageData[imageFrame][sector];
	}
	else
	{
		return 0x0;
	}
}

uint8_t imageClass::getEnable(uint8_t imageFrame)
{
	return imageData[imageFrame][3];
}

void imageClass::cyclePatterns(unsigned long currentTime)
{
	startTime = currentTime;
	switch (currentPattern)
	{
		case 1:
			spiral();
			currentPattern++;
			break;
		case 2:
			checkers();
			currentPattern++;
			break;
		case 3:
			frames();
			currentPattern = 1;
			break;
		default:
			spiral();
			currentPattern = 1;
			break;
	}
}

void imageClass::spiral(unsigned long currentTime)
{
	startTime = currentTime;
	spiral();
}

void imageClass::spiral()
{
	uint8_t step = 0;
	uint8_t pattern[8] = {B00000111, B00001110, B00011100, B00111000, B01110000, B11100000, B11000001, B10000011};
	for(int frame = 0; frame < FRAMES; frame++)
	{
		// Set the bytes
		for(int sector = 0; sector < 3; sector++)
		{
			imageData[frame][sector] = pattern[step];
		}
		imageData[frame][3] = 0x3;
		if(step < 7)step++;
		else step = 0;
	}
}

void imageClass::checkers(unsigned long currentTime)
{
	startTime = currentTime;
	checkers();
}

void imageClass::checkers()
{
	for(int frame = 0; frame < FRAMES; frame++)
	{
		// Set the bytes
		for(int sector = 0; sector < 3; sector++)
		{
			imageData[frame][sector] = B11001100;
		}

		// Set opposite the bytes in the next frame
		if (frame++ < FRAMES)
		{
			for(int sector = 0; sector < 3; sector++)
			{
				imageData[frame][sector] = B00110011;
			}
		}

		imageData[frame][3] = 0x3;
	}
}

void imageClass::frames(unsigned long currentTime)
{
	startTime = currentTime;
	frames();
}

void imageClass::frames()
{
	for(int frame = 0; frame < FRAMES; frame++)
	{
		// Set the bytes
		for(int sector = 0; sector < 3; sector++)
		{
			imageData[frame][sector] = B11111111;
		}

		if((frame % 2) == 1)
		{
			imageData[frame][3] = 0x1;
		}
		else
		{
			imageData[frame][3] = 0x2;
		}
	}
}